==> aws-cdk-scala_2.13-0.5.1-sources.jar: io/burkard/cdk/services/codebuild/CfnProject.scala <==
package io.burkard.cdk.services.codebuild

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnProject {

  def apply(
    internalResourceId: String,
    artifacts: software.amazon.awscdk.services.codebuild.CfnProject.ArtifactsProperty,
    source: software.amazon.awscdk.services.codebuild.CfnProject.SourceProperty,
    serviceRole: String,
    environment: software.amazon.awscdk.services.codebuild.CfnProject.EnvironmentProperty,
    name: Option[String] = None,
    description: Option[String] = None,
    tags: Option[List[_ <: software.amazon.awscdk.CfnTag]] = None,
    logsConfig: Option[software.amazon.awscdk.services.codebuild.CfnProject.LogsConfigProperty] = None,
    secondarySourceVersions: Option[List[_]] = None,
    vpcConfig: Option[software.amazon.awscdk.services.codebuild.CfnProject.VpcConfigProperty] = None,
    badgeEnabled: Option[Boolean] = None,
    cache: Option[software.amazon.awscdk.services.codebuild.CfnProject.ProjectCacheProperty] = None,
    buildBatchConfig: Option[software.amazon.awscdk.services.codebuild.CfnProject.ProjectBuildBatchConfigProperty] = None,
    triggers: Option[software.amazon.awscdk.services.codebuild.CfnProject.ProjectTriggersProperty] = None,
    concurrentBuildLimit: Option[Number] = None,
    resourceAccessRole: Option[String] = None,
    fileSystemLocations: Option[List[_]] = None,
    secondarySources: Option[List[_]] = None,
    secondaryArtifacts: Option[List[_]] = None,
    queuedTimeoutInMinutes: Option[Number] = None,
    sourceVersion: Option[String] = None,
    encryptionKey: Option[String] = None,
    timeoutInMinutes: Option[Number] = None,
    visibility: Option[String] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.codebuild.CfnProject =
    software.amazon.awscdk.services.codebuild.CfnProject.Builder
      .create(stackCtx, internalResourceId)
      .artifacts(artifacts)
      .source(source)
      .serviceRole(serviceRole)
      .environment(environment)
      .name(name.orNull)
      .description(description.orNull)
      .tags(tags.map(_.asJava).orNull)
      .logsConfig(logsConfig.orNull)
      .secondarySourceVersions(secondarySourceVersions.map(_.asJava).orNull)
      .vpcConfig(vpcConfig.orNull)
      .badgeEnabled(badgeEnabled.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .cache(cache.orNull)
      .buildBatchConfig(buildBatchConfig.orNull)
      .triggers(triggers.orNull)
      .concurrentBuildLimit(concurrentBuildLimit.orNull)
      .resourceAccessRole(resourceAccessRole.orNull)
      .fileSystemLocations(fileSystemLocations.map(_.asJava).orNull)
      .secondarySources(secondarySources.map(_.asJava).orNull)
      .secondaryArtifacts(secondaryArtifacts.map(_.asJava).orNull)
      .queuedTimeoutInMinutes(queuedTimeoutInMinutes.orNull)
      .sourceVersion(sourceVersion.orNull)
      .encryptionKey(encryptionKey.orNull)
      .timeoutInMinutes(timeoutInMinutes.orNull)
      .visibility(visibility.orNull)
      .build()
}

==> aws-cdk-scala_3-0.10.0-sources.jar: io/burkard/cdk/services/codebuild/CfnProject.scala <==
package io.burkard.cdk.services.codebuild

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnProject {

  def apply(
    internalResourceId: String,
    artifacts: software.amazon.awscdk.services.codebuild.CfnProject.ArtifactsProperty,
    source: software.amazon.awscdk.services.codebuild.CfnProject.SourceProperty,
    serviceRole: String,
    environment: software.amazon.awscdk.services.codebuild.CfnProject.EnvironmentProperty,
    name: Option[String] = None,
    description: Option[String] = None,
    tags: Option[List[_ <: software.amazon.awscdk.CfnTag]] = None,
    logsConfig: Option[software.amazon.awscdk.services.codebuild.CfnProject.LogsConfigProperty] = None,
    secondarySourceVersions: Option[List[_]] = None,
    vpcConfig: Option[software.amazon.awscdk.services.codebuild.CfnProject.VpcConfigProperty] = None,
    badgeEnabled: Option[Boolean] = None,
    cache: Option[software.amazon.awscdk.services.codebuild.CfnProject.ProjectCacheProperty] = None,
    buildBatchConfig: Option[software.amazon.awscdk.services.codebuild.CfnProject.ProjectBuildBatchConfigProperty] = None,
    triggers: Option[software.amazon.awscdk.services.codebuild.CfnProject.ProjectTriggersProperty] = None,
    concurrentBuildLimit: Option[Number] = None,
    resourceAccessRole: Option[String] = None,
    fileSystemLocations: Option[List[_]] = None,
    secondarySources: Option[List[_]] = None,
    secondaryArtifacts: Option[List[_]] = None,
    queuedTimeoutInMinutes: Option[Number] = None,
    sourceVersion: Option[String] = None,
    encryptionKey: Option[String] = None,
    timeoutInMinutes: Option[Number] = None,
    visibility: Option[String] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.codebuild.CfnProject =
    software.amazon.awscdk.services.codebuild.CfnProject.Builder
      .create(stackCtx, internalResourceId)
      .artifacts(artifacts)
      .source(source)
      .serviceRole(serviceRole)
      .environment(environment)
      .name(name.orNull)
      .description(description.orNull)
      .tags(tags.map(_.asJava).orNull)
      .logsConfig(logsConfig.orNull)
      .secondarySourceVersions(secondarySourceVersions.map(_.asJava).orNull)
      .vpcConfig(vpcConfig.orNull)
      .badgeEnabled(badgeEnabled.map(Boolean.box).orNull)
      .cache(cache.orNull)
      .buildBatchConfig(buildBatchConfig.orNull)
      .triggers(triggers.orNull)
      .concurrentBuildLimit(concurrentBuildLimit.orNull)
      .resourceAccessRole(resourceAccessRole.orNull)
      .fileSystemLocations(fileSystemLocations.map(_.asJava).orNull)
      .secondarySources(secondarySources.map(_.asJava).orNull)
      .secondaryArtifacts(secondaryArtifacts.map(_.asJava).orNull)
      .queuedTimeoutInMinutes(queuedTimeoutInMinutes.orNull)
      .sourceVersion(sourceVersion.orNull)
      .encryptionKey(encryptionKey.orNull)
      .timeoutInMinutes(timeoutInMinutes.orNull)
      .visibility(visibility.orNull)
      .build()
}
